@@ -3,8 +3,12 @@
 Version code adopted from Django development version.
 https://github.com/django/django
 """
-VERSION = (0, 17, 0, 'final', 0)
-default_app_config = 'modeltranslation.apps.ModeltranslationConfig'
+import django
+
+VERSION = (0, 17, 4, 'final', 0)
+
+if django.VERSION < (3, 2):
+    default_app_config = 'modeltranslation.apps.ModeltranslationConfig'
 
 
 def get_version(version=None):
@@ -54,9 +58,13 @@ def get_git_changeset():
 
     repo_dir = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
     git_log = subprocess.Popen(
-        'git log --pretty=format:%ct --quiet -1 HEAD', stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE, shell=True, cwd=repo_dir,
-        universal_newlines=True)
+        'git log --pretty=format:%ct --quiet -1 HEAD',
+        stdout=subprocess.PIPE,
+        stderr=subprocess.PIPE,
+        shell=True,
+        cwd=repo_dir,
+        universal_newlines=True,
+    )
     timestamp = git_log.communicate()[0]
     try:
         timestamp = datetime.datetime.utcfromtimestamp(int(timestamp))
